
import es
import sys,os
import traceback

info = es.AddonInfo()
info.name        = "QuakeLog"
info.version     = "1.3P"
info.author      = "*XYZ*SaYnt"
info.url         = "http://addons.eventscripts.com/addons/view/quakelog"
info.basename    = "quakelog"
info.description = "Logs Quake style kill streaks for use with hlstatsx/psychostats"


triggers = {}
streak = {}
min_streak = 100




def load():
    es.msg("QuakeLog %s loaded.  Script by *XYZ*SaYnt." % info.version)
    es.regsaycmd("quakedump","quakelog/dump","Writes internal quakelog information")
    es.set("quakelog_version",info.version)
    es.makepublic("quakelog_version")
    init_triggers()

def unload():
    es.unregsaycmd('quakedump')

def dump():  
    es.log("QL" + str(triggers)) 
    es.log("QL" + str(streak))
    es.log("QL" + str(es.getUseridList()))


#This is our custom version of statlog until the python version comes out.
def statlog(userid,event):
    es.server.queuecmd("statlog " + str(userid) + " " + event)

def init_triggers():
    global min_streak
    global triggers
    triggers.clear()
    min_streak = 100
    init_trigger("mani_quake_dominating_trigger_count","Quake_Dominating")
    init_trigger("mani_quake_rampage_trigger_count","Quake_Rampage")
    init_trigger("mani_quake_killing_spree_trigger_count","Quake_KillingSpree")
    init_trigger("mani_quake_monster_kill_trigger_count","Quake_MonsterKill")
    init_trigger("mani_quake_unstoppable_trigger_count","Quake_Unstoppable")
    init_trigger("mani_quake_ultra_kill_trigger_count","Quake_UltraKill")
    init_trigger("mani_quake_god_like_trigger_count","Quake_GodLike")
    init_trigger("mani_quake_wicked_sick_trigger_count","Quake_WickedSick")
    init_trigger("mani_quake_ludicrous_kill_trigger_count","Quake_LudicrousKill")
    init_trigger("mani_quake_holy_shit_trigger_count","Quake_HolyShit")

def init_trigger(manivar,trigger):
    global triggers
    global min_streak
    if int(es.exists("variable",manivar)):
        kills = int(es.ServerVar(manivar))
        min_streak = min(min_streak,kills)
        triggers[kills] = trigger 

def round_start(ev): 
    if len(triggers) != 10:
        init_triggers()

# following the model of ccbalance, we expunge everyone on map change.  Players
# will get picked back up in player_death.
def es_map_start(ev):
    streak.clear()
    
    
def player_disconnect(ev):
    userid = int(ev['userid'])
    if userid in streak:
        del streak[userid] 

def player_death(ev):
    global min_streak
    target = int(ev['userid'])
    attacker = int(ev['attacker'])
    
    allplayers = es.getUseridList()
       
    if attacker in allplayers:
        if target not in streak:
            streak[target] = 0 
        if attacker not in streak:
            streak[attacker] = 0
    
        #reset the killstreak for the dying player to 0
        streak[target] = 0

        #add one to the count for the killing player
        streak[attacker] += 1
 
        kills = streak[attacker]
        if kills >= min_streak:
            if kills in triggers:
                statlog(str(attacker),triggers[kills])        
                name = es.getplayername(str(attacker))
                es.msg("LOGGED: " + triggers[kills] + " for " + name) 





def except_hook(type, value, tb): 
   error_list = traceback.format_exception(type, value, tb)
   for message in error_list:
      es.log("[EXC] " + message.strip())


sys.excepthook = except_hook
